.. _api:

ESMValCore API Reference
========================

ESMValCore is mostly used as a commandline tool. However, it is also possibly to use (parts of) ESMValTool as a
library. This section documents the public API of ESMValCore.

.. toctree::
   :maxdepth: 1

   esmvalcore.cmor
   esmvalcore.config
   esmvalcore.dataset
   esmvalcore.esgf
   esmvalcore.exceptions
   esmvalcore.iris_helpers
   esmvalcore.local
   esmvalcore.preprocessor
   esmvalcore.typing
   esmvalcore.experimental
